# netzeus-core-config
NetZeus Core Config Module

This module is intended to be installed for any core modules and plugins. Common configuration should be shared within each container using a local env file `~/.netzeus_env`.